sid!() { /* proc-macro */ }Expand description
The sid macro will parse/validate a SID at compile time. SIDs require heap allocation, and thus, cannot be created in const contexts. The recommended approach for static SIDs is to wrap the call in a std::sync::LazyLock.